Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(133)

Unified Diff: ui/base/resource/resource_bundle_mac.mm

Issue 7144007: Improve and unify Mac OS X run-time version checks (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/apple_apsl/README.chromium ('k') | webkit/plugins/npapi/plugin_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/base/resource/resource_bundle_mac.mm
===================================================================
--- ui/base/resource/resource_bundle_mac.mm (revision 88826)
+++ ui/base/resource/resource_bundle_mac.mm (working copy)
@@ -11,7 +11,6 @@
#include "base/mac/mac_util.h"
#include "base/memory/scoped_nsobject.h"
#include "base/synchronization/lock.h"
-#include "base/sys_info.h"
#include "base/sys_string_conversions.h"
#include "ui/gfx/image.h"
@@ -48,13 +47,8 @@
// static
FilePath ResourceBundle::GetLargeIconResourcesFilePath() {
- int32 major = 0;
- int32 minor = 0;
- int32 bugfix = 0;
- base::SysInfo::OperatingSystemVersionNumbers(&major, &minor, &bugfix);
-
- // Only load the large resource pak on if we're running on 10.7 or above.
- if (major > 10 || (major == 10 && minor >= 7))
+ // Only load the large resource pak when running on 10.7 or later.
+ if (base::mac::IsOSLionOrLater())
return GetResourcesPakFilePath(@"theme_resources_large", nil);
else
return FilePath();
« no previous file with comments | « third_party/apple_apsl/README.chromium ('k') | webkit/plugins/npapi/plugin_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698